@@ -30,14 +30,7 @@
  *
  */
 
-#if (HAVE_CONFIG_H)
-#include "../include/config.h"
-#endif
-#if (!(_WIN32) || (__CYGWIN__)) 
-#include "../include/libnet.h"
-#else
-#include "../include/win32/libnet.h"
-#endif
+#include "common.h"
 
 libnet_ptag_t
 libnet_build_tcp(
@@ -56,7 +49,7 @@ libnet_build_tcp(
     if (payload_s && !payload)
     {
         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-			    "%s(): payload inconsistency\n", __func__);
+			    "%s(): payload inconsistency", __func__);
         return -1;
     }
 
@@ -207,7 +200,7 @@ libnet_ptag_t ptag)
     if (options_s > LIBNET_MAXOPTION_SIZE)
     {
         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-            "%s(): options list is too large %d\n", __func__, options_s);
+            "%s(): options list is too large %d", __func__, options_s);
         return (-1);
     }
 
@@ -311,4 +304,9 @@ bad:
     return (-1);
 }
 
-/* EOF */
+/**
+ * Local Variables:
+ *  indent-tabs-mode: nil
+ *  c-file-style: "stroustrup"
+ * End:
+ */
