@@ -24,32 +24,21 @@
  * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#if (HAVE_CONFIG_H)
-#include "../include/config.h"
-#endif
+#include "common.h"
+
+
 #include <sys/time.h>
 
 #include <net/if.h>
-#if (__GLIBC__)
 #include <netinet/if_ether.h>
 #include <net/if_arp.h>
-#else
-#include <linux/if_arp.h>
-#include <linux/if_ether.h>
-#endif
 
 #if (HAVE_PACKET_SOCKET)
 #ifndef SOL_PACKET
 #define SOL_PACKET 263
 #endif  /* SOL_PACKET */
-#if __GLIBC__ >= 2 && __GLIBC_MINOR >= 1
 #include <netpacket/packet.h>
 #include <net/ethernet.h>     /* the L2 protocols */
-#else
-#include <asm/types.h>
-#include <linux/if_packet.h>
-#include <linux/if_ether.h>   /* The L2 protocols */
-#endif
 #endif  /* HAVE_PACKET_SOCKET */
 
 #include "../include/libnet.h"
@@ -125,6 +114,7 @@ libnet_open_link(libnet_t *l)
         case ARPHRD_SLIP6:
         case ARPHRD_CSLIP6:
         case ARPHRD_PPP:
+        case ARPHRD_NONE:
             l->link_type = DLT_RAW;
             break;
         case ARPHRD_FDDI:
@@ -141,7 +131,7 @@ libnet_open_link(libnet_t *l)
 
         default:
             snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-                "unknown physical layer type 0x%x\n",
+                "unknown physical layer type 0x%x",
                 ifr.ifr_hwaddr.sa_family);
         goto bad;
     }
@@ -157,7 +147,7 @@ libnet_open_link(libnet_t *l)
     if (setsockopt(l->fd, SOL_SOCKET, SO_BROADCAST, &n, sizeof(n)) == -1)
     {
         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-		 "%s: set SO_BROADCAST failed: %s\n",
+		 "%s: set SO_BROADCAST failed: %s",
 		 __func__, strerror(errno));
         goto bad;
     }
@@ -242,7 +232,7 @@ libnet_write_link(libnet_t *l, const uint8_t *packet, uint32_t size)
     if (c != size)
     {
         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-                "libnet_write_link(): only %d bytes written (%s)\n", c,
+                "libnet_write_link(): only %d bytes written (%s)", c,
                 strerror(errno));
     }
     return (c);
@@ -254,11 +244,6 @@ libnet_get_hwaddr(libnet_t *l)
 {
     int fd;
     struct ifreq ifr;
-    struct libnet_ether_addr *eap;
-    /*
-     *  XXX - non-re-entrant!
-     */
-    static struct libnet_ether_addr ea;
 
     if (l == NULL)
     { 
@@ -270,7 +255,7 @@ libnet_get_hwaddr(libnet_t *l)
         if (libnet_select_device(l) == -1)
         {   
             snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
-                    "libnet_get_hwaddr: can't figure out a device to use\n");
+                    "libnet_get_hwaddr: can't figure out a device to use");
             return (NULL);
         }
     }
@@ -287,30 +272,28 @@ libnet_get_hwaddr(libnet_t *l)
     }
 
     memset(&ifr, 0, sizeof(ifr));
-    eap = &ea;
-   	strncpy(ifr.ifr_name, l->device, sizeof(ifr.ifr_name) - 1);
+    strncpy(ifr.ifr_name, l->device, sizeof(ifr.ifr_name) - 1);
     ifr.ifr_name[sizeof(ifr.ifr_name) - 1] = '\0';
 
-    if (ioctl(fd, SIOCGIFHWADDR, (int8_t *)&ifr) < 0)
+    if (ioctl(fd, SIOCGIFHWADDR, &ifr) < 0)
     {
         close(fd);
         snprintf(l->err_buf, LIBNET_ERRBUF_SIZE,
                 "ioctl: %s", strerror(errno));
         goto bad;
     }
-    memcpy(eap, &ifr.ifr_hwaddr.sa_data, ETHER_ADDR_LEN);
     close(fd);
-    return (eap);
+
+    return memcpy(l->link_addr.ether_addr_octet, &ifr.ifr_hwaddr.sa_data,
+                  ETHER_ADDR_LEN);
 
 bad:
     return (NULL);
 }
 
-/* ---- Emacs Variables ----
+/**
  * Local Variables:
- * c-basic-offset: 4
- * indent-tabs-mode: nil
+ *  indent-tabs-mode: nil
+ *  c-file-style: "stroustrup"
  * End:
  */
-
-/* EOF */
